@@ -14,11 +14,16 @@ _HELP_MESSAGE_BINARY = """
         -p <binary_path>\t\t    Path to analyze binaries (Default: current directory)
         -h\t\t\t\t    Print help message
         -v\t\t\t\t    Print FOSSLight Binary Scanner version
+        -s\t\t\t\t    Extract only the binary list in simple mode
+        -e <path>\t\t\t    Path to exclude from analysis (files and directories)
         -o <output_path>\t\t    Output path
         \t\t\t\t    (If you want to generate the specific file name, add the output path with file name.)
-        -f <format>\t\t\t    Output file format (excel, csv, opossum, yaml)
+        -f <format> [<format> ...]\t    Output file formats (excel, csv, opossum, yaml)
+        \t\t\t\t    Multiple formats can be specified separated by space.
         -d <db_url>\t\t\t    DB Connection(format :'postgresql://username:password@host:port/database_name')
-        --notice\t\t\t    Print the open source license notice text."""
+        --notice\t\t\t    Print the open source license notice text.
+        --no_correction\t\t\t    Enter if you don't want to correct OSS information with sbom-info.yaml
+        --correct_fpath <path>\t\t    Path to the sbom-info.yaml file"""
 
 
 def print_help_msg():
